@@ -287,10 +287,17 @@ def zernpol_pupil(nma, pupil: PupilMask, inpupil_only=False, normalized: bool=Tr
              The last dimension must be 2  
         pupil (:class:`PupilMask`): The pupil mask object define the mask array and how the zernike
               mode will be built inside the pupil image
+        inpupil_only (boolean, optional): If True return only the coeeficient defined inside 
+              the pupil mask. This allow to have smaller memory footprint when the illuminated 
+              part of the pupil if much smaller than the full image. 
+              An image can still be reconstructed from the pupil mask object with the reconstruct method
         normalized (boolean, optional): if True (default), the polynom is normalized to 1
      
     Return:
-        z (array like) : float of array with shape  nma.shape[:-1]+pupil.mask.shape  
+        z (array like) : float of array with shape:
+                - nma.shape[:-1]+pupil.mask.shape if inpupil_only is False 
+                - nma.shape[:-1] + (N,) Where N is the number of "illuminated" pixel in the pupil 
+            
     
     Example:
     
@@ -299,11 +306,17 @@ def zernpol_pupil(nma, pupil: PupilMask, inpupil_only=False, normalized: bool=Tr
         >>> from matplotlib.pylab import plt 
         >>> from zernpol import PupilDisk, zernpol, zernpol_pupil
         >>> disk = PupilDisk(100) # 100 diameter in user unit
-        >>> disk_mask = disk.make_mask( (120,120), 1.0, center=(60.,60) )
+        >>> disk_mask = disk.make_mask( (180,180), 1.0, center=(60.,90) )
         >>> z = zernpol_pupil( zernpol(5), disk_mask)
         >>> plt.imshow(z)
         >>> plt.show()
-          
+    
+    ::
+
+        >>> z1 = zernpol_pupil( zernpol(5), disk_mask)
+        >>> z2 = zernpol_pupil( zernpol(5), disk_mask, inpupil_only=True)
+        >>> print( z1.shape, z2.shape, disk_mask.reconstruct(z2).shape )
+
         
     """     
     mask = pupil.mask
@@ -339,7 +352,7 @@ class Zernpol(namedtuple('BaseZernpolTuple',['n', 'm'])):
     Methods:
         func_pol : zernike polynom from polar coordinates
         func_cart : zernike polynom from cartezian coordinates 
-    
+        func_pupil: zernike polynom image from a :class:`PupilMask`
     Attributes:
         name, long_name (str): name and long name ( up to 'quadrafoil_0' noll=15)
         latex (str) : LateX formula (without the '$' bracket)
@@ -453,8 +466,24 @@ class Zernpol(namedtuple('BaseZernpolTuple',['n', 'm'])):
         return zernpol_func_cart(self, x, y, normalized=normalized, masked=masked)
     
     def func_pupil(self, pupil: PupilMask, inpupil_only=False,  normalized: bool = True):
-        return zernpol_pupil(self, pupil, inpupil_only=inpupil_only, normalized=normalized)
+        """ Zernike Polynomial from a :class:`PupilMask`
     
+        Args:
+            pupil (:class:`PupilMask`): The pupil mask object define the mask array and how the zernike
+                  mode will be built inside the pupil image
+            inpupil_only (boolean, optional): If True return only the coeeficient defined inside 
+                  the pupil mask. This allow to have smaller memory footprint when the illuminated 
+                  part of the pupil if much smaller than the full image. 
+                  An image can still be reconstructed from the pupil mask object with the reconstruct method
+            normalized (boolean, optional): if True (default), the polynom is normalized to 1
+         
+        Return:
+            z (array like) : float of array with shape:
+                    - nma.shape[:-1]+pupil.mask.shape if inpupil_only is False 
+                    - nma.shape[:-1] + (N,) Where N is the number of "illuminated" pixel in the pupil 
+     
+            return zernpol_pupil(self, pupil, inpupil_only=inpupil_only, normalized=normalized)
+        """ 
     @property
     def info(self):
         """ All information inside a dictionary """
@@ -583,6 +612,8 @@ def zernpol(input: Union[int,Tuple[int,int],list],
                - if a 2 tuple this is un-anbigously the zernike polynom coefficients
                - if str return the given zernike polynom coeficient (if known or raise error otherwhise)   
                - if iterable walk throug the item and interpret them 
+        system: (ZIS, optional): used system If None the ZIS.Default is used as default system  
+            
     
     Return:
         z : a list of a :class:`Zernpol` object function to input type  
@@ -731,6 +762,12 @@ def ansi_to_zernpol(j):
     except KeyError:
         raise ValueError('Ansi indice <0 or above limit')
 
+
+def _zernpol_to_fringe_formula(n,m):
+    # fringe system is defined up to 37 but the formulae is only valid up 
+    # to 36 
+    return (1+ (n+abs(m))//2)**2 -2*abs(m) + (1-np.sign(m))//2
+
 def zernpol_to_fringe(nm):
     """ Convert zernike polynomials (n,m) to Fringe/University of Arizona indice 
     
@@ -740,14 +777,23 @@ def zernpol_to_fringe(nm):
     Return:
         j (int) : Fringe/University of Arizona indice number
     
-    see https://en.wikipedia.org/wiki/Zernike_polynomials 
+    see https://en.wikipedia.org/wiki/Zernike_polynomials
+    and https://wp.optics.arizona.edu/jsasian/wp-content/uploads/sites/33/2018/04/Schwiegerling-Zernike-2018.pdf
+
     """
     n,m = nm
     if (n-m)%2:
-        raise ValueError(f'{n},{m} is not a valid zernike polynom pair')    
-    return (1+ (n+abs(m))//2)**2 -2*abs(m) + (1-np.sign(m))//2
+        raise ValueError(f'{n},{m} is not a valid zernike polynom pair') 
+    j = _zernpol_to_fringe_formula(n,m) 
+    # Fringe formulae is only valid up to 36 but an extra sherical aberation (37)
+    # correspond to 49 as returned by the formula 
+    if j==49:  
+        return 37
+    if j>36:
+        raise ValueError(f'{n},{m} is not defined inside the Fringe indice system')
+    return j 
 
-_fringe_to_zernpol_loockup = { zernpol_to_fringe(nm):nm for nm in _noll_pol_triangle } 
+_fringe_to_zernpol_loockup = { _zernpol_to_fringe_formula(*nm):nm for nm in _noll_pol_triangle } 
 def fringe_to_zernpol(j):
     """ convert Fringe/University of Arizona indice to zernike polynoms 
     
@@ -759,10 +805,14 @@ def fringe_to_zernpol(j):
     
     see https://en.wikipedia.org/wiki/Zernike_polynomials
     """
+    if j<1 or j>37:
+        raise ValueError(f'Fringe indice must be between 1<=i<=37 got {j}')
+    if j == 37:
+       return Zernpol(12,0) # the loockup is good only until 36  
     try:
         return _fringe_to_zernpol_loockup[j]
     except KeyError:
-        raise ValueError('Fringe indice <1 or above limit')
+        raise ValueError(f'BUG ! Fringe indice must be between 1<=i<=37 got {j}')
 
 def zernpol_to_wyant(nm):
     """ convert zernike polynomials (n,m) to Wyant indice 
